==> haskell-blaze-markup-0.8.3.0-76-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-markup
version:              0.8.3.0
visibility:           public
id:                   blaze-markup-0.8.3.0-BQHgx8yAxJB0rzkVyHbGy
key:                  blaze-markup-0.8.3.0-BQHgx8yAxJB0rzkVyHbGy
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  684edacfd6268f4efa7761c7cafd1539
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-9.4.8/site-local/blaze-markup-0.8.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/blaze-markup-0.8.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/blaze-markup-0.8.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-markup
hs-libraries:         HSblaze-markup-0.8.3.0-BQHgx8yAxJB0rzkVyHbGy
depends:
    base-4.17.2.1 blaze-builder-0.4.4-8DNZG0v2dXo77KXKrz7TGj
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-blaze-markup-0.8.3.0-77-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-blaze-markup.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 blaze-markup
version:              0.8.3.0
visibility:           public
id:                   blaze-markup-0.8.3.0-1slEV1JTVXCHBVRvUtps3k
key:                  blaze-markup-0.8.3.0-1slEV1JTVXCHBVRvUtps3k
license:              BSD-3-Clause
maintainer:           Jasper Van der Jeugt <m@jaspervdj.be>
author:               Jasper Van der Jeugt, Simon Meier, Deepak Jois
stability:            Experimental
homepage:             http://jaspervdj.be/blaze
synopsis:             A blazingly fast markup combinator library for Haskell
description:
    Core modules of a blazingly fast markup combinator library for the Haskell
    programming language. The Text.Blaze module is a good
    starting point, as well as this tutorial:
    <http://jaspervdj.be/blaze/tutorial.html>.

category:             Text
abi:                  e67c289210b8b75d83ccef035bd3096b
exposed:              True
exposed-modules:
    Text.Blaze Text.Blaze.Internal Text.Blaze.Renderer.Pretty
    Text.Blaze.Renderer.String Text.Blaze.Renderer.Text
    Text.Blaze.Renderer.Utf8

import-dirs:          /usr/lib/ghc-9.4.8/site-local/blaze-markup-0.8.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/blaze-markup-0.8.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/blaze-markup-0.8.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-blaze-markup
hs-libraries:         HSblaze-markup-0.8.3.0-1slEV1JTVXCHBVRvUtps3k
depends:
    base-4.17.2.1 blaze-builder-0.4.4-hpTW57LOkJwByfG1pJQ0
    bytestring-0.11.5.3 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-blaze-markup/html/blaze-markup.haddock

haddock-html:         /usr/share/doc/haskell-blaze-markup/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
